# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OutboundEmailBouncedWebhookEvent", "Data", "DataRecipient"]


class DataRecipient(BaseModel):
    email_address: str = FieldInfo(alias="emailAddress")

    action: Optional[str] = None

    diagnostic_code: Optional[str] = FieldInfo(alias="diagnosticCode", default=None)

    status: Optional[str] = None


class Data(BaseModel):
    bounced_at: str = FieldInfo(alias="bouncedAt")

    bounce_type: Literal["Permanent", "Transient", "Undetermined"] = FieldInfo(alias="bounceType")

    message_id: str = FieldInfo(alias="messageId")

    recipients: List[DataRecipient]

    bounce_sub_type: Optional[str] = FieldInfo(alias="bounceSubType", default=None)

    email_id: Optional[str] = FieldInfo(alias="emailId", default=None)


class OutboundEmailBouncedWebhookEvent(BaseModel):
    attempt: int

    data: Data

    event: Literal["outbound.email.bounced"]

    timestamp: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import Annotated, TypeAlias

from .._utils import PropertyInfo
from .outbound_email_opened_webhook_event import OutboundEmailOpenedWebhookEvent
from .inbound_email_received_webhook_event import InboundEmailReceivedWebhookEvent
from .outbound_email_bounced_webhook_event import OutboundEmailBouncedWebhookEvent
from .outbound_email_clicked_webhook_event import OutboundEmailClickedWebhookEvent
from .outbound_email_rejected_webhook_event import OutboundEmailRejectedWebhookEvent
from .outbound_email_delivered_webhook_event import OutboundEmailDeliveredWebhookEvent
from .outbound_email_complained_webhook_event import OutboundEmailComplainedWebhookEvent

__all__ = ["UnwrapWebhookEvent"]

UnwrapWebhookEvent: TypeAlias = Annotated[
    Union[
        InboundEmailReceivedWebhookEvent,
        OutboundEmailDeliveredWebhookEvent,
        OutboundEmailBouncedWebhookEvent,
        OutboundEmailComplainedWebhookEvent,
        OutboundEmailRejectedWebhookEvent,
        OutboundEmailOpenedWebhookEvent,
        OutboundEmailClickedWebhookEvent,
    ],
    PropertyInfo(discriminator="event"),
]
